@@ -32,8 +32,8 @@
 #' dir_map(DIR)
 #' }
 dir_map <- 
-function(loc = "CLEANED_TRANSCRIPTS", obj.prefix = "dat", use.path = TRUE,
-    col.names = c("person", "dialogue"), file = NULL, 
+function(loc = "DATA/TRANSCRIPTS/CLEANED_TRANSCRIPTS", obj.prefix = "dat", 
+    use.path = TRUE, col.names = c("person", "dialogue"), file = NULL, 
     copy2clip = interactive()) {
   
     if (Sys.info()["sysname"] != "Windows") {
