@@ -45,11 +45,6 @@
 #' (pres2 <- removeSparseTerms(pres, .3))
 #' plot(pres2, corThreshold = 0.95)
 #' 
-#' ## Latent Semantic Analysis
-#' library(lsa)
-#' lsa(tdm(x), dims=dimcalc_share())
-#' lsa(tdm(DATA$state, DATA$person), dims=dimcalc_share())
-#' 
 #' shorts <- all_words(pres_debates2012)[,1][nchar(all_words(
 #'     pres_debates2012)[,1]) < 4]
 #' 
@@ -60,19 +55,6 @@
 #' DocTermMat2 <- with(pres_debates2012, dtm(dialogue, list(person, time), stopwords = SW))
 #' DocTermMat2 <- removeSparseTerms(DocTermMat2,0.95)
 #' DocTermMat2 <- DocTermMat2[rowSums(as.matrix(DocTermMat2))> 0,]
-#' 
-#' out <- lsa(DocTermMat2, 6)
-#' out$tk
-#' out2 <- colsplit2df(matrix2df(out$tk), new.names = qcv(Person, Time))
-#' out2$Person <- factor(out2$Person, 
-#'     levels = names(sort(colSums(with(pres_debates2012, 
-#'         wfm(dialogue, person, stopwords = SW))), TRUE))
-#' )
-#' colnames(out2) <- gsub("X", "Topic ", colnames(out2))
-#' 
-#' qheat(out2, facet.vars = "Time", high="darkgreen", plot=FALSE) + 
-#'     theme(legend.title=element_blank()) + 
-#'     guides(fill = guide_colorbar(barwidth = .5, barheight = 12))
 #'     
 #' ## Correspondence Analysis
 #' library(ca)
@@ -299,6 +281,23 @@
 #'     top = 5, stopwords = Top100Words)
 #' apply_as_df(reuters, dispersion_plot, match.terms = finds[, 1],
 #'     total.color = NULL)
+#'     
+#' ## Filter for Term Document Matrix/Document Term Matrix
+#' library(tm)
+#' data(crude)
+#' 
+#' (tdm_in <- TermDocumentMatrix(crude, control = list(stopwords = TRUE)))
+#' Filter(tdm_in, 5)
+#' 
+#' (dtm_in <- DocumentTermMatrix(crude, control = list(stopwords = TRUE)))
+#' Filter(dtm_in, 5)
+#' 
+#' ## Filter particular words based on max/min values in wfm
+#' v <- with(DATA, wfm(state, list(sex, adult)))
+#' Filter(dtm_in, 5, 7)
+#' Filter(dtm_in, 4, 4)
+#' Filter(tdm_in, 3, 4)
+#' Filter(tdm_in, 3, 4, stopwords = Top200Words)
 #' }
 tdm <- function(text.var, grouping.var = NULL, vowel.check = TRUE, ...) {
 
@@ -756,3 +755,62 @@ apply_as_df <- function(tm.corpus, qdapfun, ..., stopwords = NULL,
 
 }
 
+
+#' Filter
+#' 
+#' \code{Filter.TermDocumentMatrix} - Filter words from a TermDocumentMatrix vector that meet 
+#' max/min word length criteria.
+#' 
+#' TermDocumentMatrix Method for Filter
+#' @rdname Filter
+#' @export
+#' @method Filter TermDocumentMatrix
+#' @return \code{Filter.TermDocumentMatrix} - Returns a matrix of the class "TermDocumentMatrix".
+Filter.TermDocumentMatrix <- function(x, min = 1, max = Inf, count.apostrophe = TRUE, 
+    stopwords = NULL, ignore.case = TRUE, ...) {
+   
+    tdm(Filter(as.wfm(x), min = min, max = max, 
+        count.apostrophe = count.apostrophe, 
+        stopwords = stopwords, ignore.case = ignore.case, ...))
+
+}
+
+#' Filter
+#' 
+#' \code{Filter.DocumentTermMatrix} - Filter words from a DocumentTermMatrix 
+#' that meet max/min word length criteria.
+#' 
+#' DocumentTermMatrix Method for Filter
+#' @rdname Filter
+#' @export
+#' @method Filter DocumentTermMatrix
+#' @return \code{Filter.DocumentTermMatrix} - Returns a matrix of the class "DocumentTermMatrix".
+Filter.DocumentTermMatrix <- function(x, min = 1, max = Inf, 
+    count.apostrophe = TRUE, stopwords = NULL, ignore.case = TRUE, ...) {
+   
+    dtm(Filter(as.wfm(x), min = min, max = max, 
+        count.apostrophe = count.apostrophe, 
+        stopwords = stopwords, ignore.case = ignore.case, ...))
+
+}
+
+
+##Removed after las archived:
+## ## Latent Semantic Analysis
+## library(lsa)
+## lsa(tdm(x), dims=dimcalc_share())
+## lsa(tdm(DATA$state, DATA$person), dims=dimcalc_share())
+
+#' 
+#' out <- lsa(DocTermMat2, 6)
+#' out$tk
+#' out2 <- colsplit2df(matrix2df(out$tk), new.names = qcv(Person, Time))
+#' out2$Person <- factor(out2$Person, 
+#'     levels = names(sort(colSums(with(pres_debates2012, 
+#'         wfm(dialogue, person, stopwords = SW))), TRUE))
+#' )
+#' colnames(out2) <- gsub("X", "Topic ", colnames(out2))
+#' 
+#' qheat(out2, facet.vars = "Time", high="darkgreen", plot=FALSE) + 
+#'     theme(legend.title=element_blank()) + 
+#'     guides(fill = guide_colorbar(barwidth = .5, barheight = 12))
